pub fn parse_with_source(
source: &str,
) -> (Result<File, Vec<ChumskyParseError>>, NamedSource<String>)Expand description
Parse Ato source code, returning both the AST and a source code wrapper for error display.
This is useful when you want to display nice error messages with miette.